@@ -28,7 +28,7 @@
 #include "account.h"
 #include "private/queuehelper_p.h"
 
-#include <QtNetwork/QNetworkRequest>
+#include <QNetworkRequest>
 
 using namespace KGAPI2;
 
@@ -65,7 +65,7 @@ void ContactDeleteJob::Private::processNextContact()
     QStringList headers;
     auto rawHeaderList = request.rawHeaderList();
     headers.reserve(rawHeaderList.size());
-    Q_FOREACH(const QByteArray &str, rawHeaderList) {
+    for (const QByteArray &str : qAsConst(rawHeaderList)) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
@@ -78,7 +78,7 @@ ContactDeleteJob::ContactDeleteJob(const ContactsList& contacts, const AccountPt
     d(new Private(this))
 {
     d->contactIds.reserve(contacts.size());
-    Q_FOREACH(const ContactPtr &contact, contacts) {
+    for (const ContactPtr &contact : contacts) {
         d->contactIds <<  contact->uid();
     }
 }
